package com.tzld.piaoquan.risk.control.service.rule;

import lombok.Getter;

import java.util.Map;

@Getter
public class BinaryOp implements Expression {
    private final Expression left;
    private final Expression right;
    private final TokenType operator;

    public BinaryOp(Expression left, Expression right, TokenType operator) {
        this.left = left;
        this.right = right;
        this.operator = operator;
    }

    @Override
    public boolean evaluate(Map<String, Double> context) {
        boolean leftVal = left.evaluate(context);
        if (operator == TokenType.OR && leftVal) {
            // Short-circuit for OR
            return true;
        }
        boolean rightVal = right.evaluate(context);
        switch (operator){
            case AND:
                return leftVal && rightVal;
            case OR:
                return leftVal || rightVal;
            default:
                throw new UnsupportedOperationException("Unsupported operator: " + operator);
        }
    }
}
