package com.tzld.piaoquan.risk.control.util;

import java.io.UnsupportedEncodingException;
import java.net.URI;
import java.net.URISyntaxException;
import java.net.URLDecoder;
import java.util.Objects;

/**
 * @author supeng
 */
public class UrlUtil {
    /**
     * 返回http Url
     *
     * @param httpDomain
     * @param url
     * @return
     */
    public static String processUrl(String httpDomain, String url) {
        if (Objects.isNull(url)) {
            return null;
        }
        String lowerUrl = url.toLowerCase();
        if (!lowerUrl.startsWith("http://") && !lowerUrl.startsWith("https://")) {
            return httpDomain + url;
        } else {
            return url;
        }
    }

    public static boolean isM3u8ByExtension(String filePath) {
        if (Objects.isNull(filePath) || filePath.trim().isEmpty()) {
            return false;
        }
        return filePath.toLowerCase().endsWith(".m3u8");
    }

    public static String getFileFormatFromUrl(String url) {
        if (url == null || url.isEmpty()) {
            return null;
        }

        try {
            url = URLDecoder.decode(url, "utf-8");
            URI uri = new URI(url);
            // 自动解码百分比编码
            String path = uri.getPath();

            String[] pathSegments = path.split("/");
            String filename = "";
            // 从后往前查找最后一个非空的路径段作为文件名
            for (int i = pathSegments.length - 1; i >= 0; i--) {
                if (!pathSegments[i].isEmpty()) {
                    filename = pathSegments[i];
                    break;
                }
            }

            int lastDotIndex = filename.lastIndexOf('.');
            if (lastDotIndex != -1 && lastDotIndex < filename.length() - 1) {
                return filename.substring(lastDotIndex + 1).toLowerCase();
            } else {
                // 无扩展名
                return "";
            }
        } catch (URISyntaxException | UnsupportedEncodingException e) {
            return "";
        }
    }

    public static void main(String[] args) {
        System.out.println("1-"+getFileFormatFromUrl("http://www.baidu.com"));
        System.out.println("2-"+getFileFormatFromUrl("https://p26-sign.douyinpic.com/tos-cn-i-dy/8a3389f159994fd3ac6a25f19a8ccf1c~tplv-dy-resize-walign-adapt-aq:540:q75.jpeg?lk3s=138a59ce&x-expires=1747911600&x-signature=rPrBxvo5sw6Am9HAGUxlowwQk%2Fk%3D&from=327834062&s=PackSourceEnum_PUBLISH&se=false&sc=cover&biz_tag=aweme_video&l=20250508195515F7E21D4D81B4C003D6B5"));
        System.out.println("3-"+getFileFormatFromUrl("https://p26.douyinpic.com/aweme/100x100/aweme-avatar/tos-cn-avt-0015_14ceddcb8d4ae3dad93e6784e2765d15.jpeg?from=2956013662"));
        System.out.println("33-"+getFileFormatFromUrl("https://p11.douyinpic.com/aweme/100x100/aweme-avatar/tos-cn-avt-0015_8baa644e98ebc9b8edcf2d07258d0406.jpeg?from=2956013662"));
        System.out.println("4-"+getFileFormatFromUrl("https://v5-h.douyinvod.com/f1f6de57cfa3b511e60fe0e5cf30f78c/6811d38e/video/tos/cn/tos-cn-ve-15c000-ce/oU4E5v1mIR8Ae8DCkPTDfEe9hzAFQ42wTucoEq/?a=1128\\u0026ch=10\\u0026cr=3\\u0026dr=0\\u0026lr=all\\u0026cd=0%7C0%7C0%7C3\\u0026cv=1\\u0026br=1500\\u0026bt=1500\\u0026cs=0\\u0026ds=6\\u0026ft=OXXf~77JWH6BMZ7Df_r0PD1IN\\u0026mime_type=video_mp4\\u0026qs=0\\u0026rc=Zzk5M2c5aDxkZDlnOzY5ZkBpM2xtZ3g5cnZwMzMzbGkzNEAyNS4vNWAuXl4xXjVhNjYuYSNjaV8xMmRzZDRhLS1kLWJzcw%3D%3D\\u0026btag=c0010e000ad200\\u0026cquery=103S_100b_105O_103Q_103R\\u0026dy_q=1745995026\\u0026feature_id=f0150a16a324336cda5d6dd0b69ed299\\u0026l=202504301437051266DB29BE2902786D43"));
        System.out.println("5-"+getFileFormatFromUrl("https://v3-c.douyinvod.com/0958ba0af49b57b46d3a01c7afe4e9e9/681ca9cf/video/tos/cn/tos-cn-ve-15c001-alinc2/okFAMe0EaXhBkBgRg6NvOPiaiAAecQD90FVpHI/?a=1128&ch=10&cr=3&dr=0&lr=all&cd=0%7C0%7C0%7C3&cv=1&br=2094&bt=2094&cs=0&ds=6&ft=OXXf~77JWH6BMgHxt_r0PD1IN&mime_type=video_mp4&qs=0&rc=ODZmaDo5ZDg2NThkNTRkOkBpajQ0b3c5cnR3MzMzNGkzM0AxMWM1YS4wXjQxLjFiMmBhYSMvX3BoMmQ0cWBhLS1kLWFzcw%3D%3D&btag=c0010e00090000&cquery=105O_103Q_103W_103Y_100b&dy_q=1746705315&feature_id=f0150a16a324336cda5d6dd0b69ed299&l=20250508195515F7E21D4D81B4C003D6B5"));
    }
}
